@@ -87,10 +87,10 @@ check_prefixes()
     # This function checks system enviroment for install prefix locations
     # and sets prefixed installation paths.
 
-    export prefix exec_prefix wrapperdir docdir sharedir plugindir
+    export prefix exec_prefix wrapperdir docdir sharedir plugindir man_dir
 
     debug_msg 0 "in check_prefixes()"
-    debug_msg 1 "enviroment = $prefix $exec_prefix $wrapperdir $docdir $sharedir $plugindir"
+    debug_msg 1 "enviroment = $prefix $exec_prefix $wrapperdir $docdir $sharedir $plugindir $man_dir"
 
     verbose="0"
 
@@ -106,19 +106,17 @@ set_prefix()
 
     test "${prefix}" || prefix="${str_defaultprefix}"
 
+    share_dir="${prefix}/share/opera"
     if test ${os} = 'FreeBSD' -o ${os} = 'OpenBSD'; then
-        wrapper_dir="${prefix}/bin"
-        doc_dir="${prefix}/share/doc/opera"
-        share_dir="${prefix}/share/opera"
         exec_dir="${share_dir}/bin"
         plugin_dir="${share_dir}/plugins"
     else
 	exec_dir="${prefix}/lib/opera/$opera_version"
-	wrapper_dir="${prefix}/bin"
-	doc_dir="${prefix}/share/doc/opera"
-	share_dir="${prefix}/share/opera"
 	plugin_dir="${prefix}/lib/opera/plugins"
     fi
+    man_dir="${prefix}/share/man"
+    doc_dir="${prefix}/share/doc/opera"
+    wrapper_dir="${prefix}/bin"
 }
 
 set_destdir()
@@ -128,6 +126,7 @@ set_destdir()
     exec_dir="${OPERADESTDIR}${exec_dir}"
     wrapper_dir="${OPERADESTDIR}${wrapper_dir}"
     doc_dir="${OPERADESTDIR}${doc_dir}"
+    man_dir="${OPERADESTDIR}${man_dir}"
     share_dir="${OPERADESTDIR}${share_dir}"
     plugin_dir="${OPERADESTDIR}${plugin_dir}"
 }
@@ -140,12 +139,12 @@ usage()
 
     echo "Usage: ${str_progname} -s"
     echo "  or:  ${str_progname} -f DEST"
-    test "$1" && echo "  or:  ${str_progname} -f EXEC_DEST WRAPPER_DEST DOC_DEST SHARE_DEST PLUGIN_DEST"
+    test "$1" && echo "  or:  ${str_progname} -f EXEC_DEST WRAPPER_DEST DOC_DEST SHARE_DEST PLUGIN_DEST MAN_DEST"
     if test "$1";
-	then echo "  or:  ${str_progname} --prefix=DEST [--exec_prefix=] [--wrapperdir=] [--docdir=] [--sharedir=] [--plugindir=]"
+	then echo "  or:  ${str_progname} --prefix=DEST [--exec_prefix=] [--wrapperdir=] [--docdir=] [--sharedir=] [--plugindir=] [--mandir=]"
 	else echo "  or:  ${str_progname} --prefix=DEST"
     fi
-    echo "  or:  ${str_progname} --exec_prefix=EXEC_DEST --wrapperdir=WRAPPER_DEST --docdir=DOC_DEST --sharedir=SHARE_DEST --plugindir=PLUGIN_DEST"
+    echo "  or:  ${str_progname} --exec_prefix=EXEC_DEST --wrapperdir=WRAPPER_DEST --docdir=DOC_DEST --mandir=MAN_DEST --sharedir=SHARE_DEST --plugindir=PLUGIN_DEST"
     test "$1" && echo
     test "$1" && echo ' or by enviroment variables:'
     test "$1" && echo "  or:  prefix=DEST ${str_progname}"
@@ -167,6 +166,8 @@ usage()
     echo '      --wrapperdir=            install Opera wrapper script to directory'
     test "$1" && echo '      $docdir'
     echo '      --docdir=                install Opera documentation to directory'
+    test "$1" && echo '      $man_dir'
+    echo '      --mandir=                install Opera manual page to directory'
     test "$1" && echo '      $sharedir'
     echo '      --sharedir=              install Opera shared files to directory'
     test "$1" && echo '      $plugindir'
@@ -252,7 +253,7 @@ case $1 in
 		then error 'abort'
 		else shift
 		fi
-	    elif test -z "$5"
+	    elif test -z "$6"
 	    then error 'missing'
 	    else
 		str_paramexec="$1"
@@ -260,7 +261,8 @@ case $1 in
 		str_paramdoc="$3"
 		str_paramshare="$4"
 		str_paramplugin="$5"
-		shift 5
+		str_paramman="$6"
+		shift 6
 	    fi
 	else error 'conflict'
 	fi
@@ -320,6 +322,20 @@ case $1 in
 	    fi
 	    ;;
 
+    --mandir=*)
+	    param=`echo "$1" | sed -e 's/--mandir=//'`
+	    shift
+	    if test "${param}"
+	    then
+		if test "$flag_mode" = '--prefix=' || test -z "$flag_mode"
+		then
+		    flag_mode='--prefix='
+		    str_paramman="${param}"
+		else error 'conflict'
+		fi
+	    fi
+	    ;;
+
     --docdir=*)
 	    param=`echo "$1" | sed -e 's/--docdir=//'`
 	    shift
@@ -539,12 +555,12 @@ select_installation_type()
 	    test "${str_paramexec}"     && exec_dir="${str_paramexec}"
 	    test "${str_paramwrapper}"  && wrapper_dir="${str_paramwrapper}"
 	    test "${str_paramdoc}"      && doc_dir="${str_paramdoc}"
+	    test "${str_paramman}"      && man_dir="${str_paramman}"
 	    test "${str_paramshare}"    && share_dir="${str_paramshare}"
 	    test "${str_paramplugin}"   && plugin_dir="${str_paramplugin}"
 	    set_destdir "${str_paramdestdir}"
 	    ;;
     esac
-
 }
 
 can_write_to()
@@ -601,6 +617,7 @@ confirm_paths()
       echo " Plugins        : ${plugin_dir}"
       echo " Shared files   : ${share_dir}"
       echo " Documentation  : ${doc_dir}"
+      echo " Manual page    : ${man_dir}"
       echo "-----------------------------------------------------------"
       if con_firm "Is this correct" "cancel"
       then return 0
@@ -672,6 +689,7 @@ change_paths()
     prompt_path "plugins" "${plugin_dir}" "plugin_dir"
     prompt_path "shared files" "${share_dir}" "share_dir"
     prompt_path "documentation" "${doc_dir}" "doc_dir"
+    prompt_path "manual page" "${man_dir}" "man_dir"
 }
 
 interactive_install()
@@ -684,7 +702,7 @@ interactive_install()
     # Test current prefixed locations.
     if test -n "${prefix}"
     then
-	if can_write_to "${exec_dir}" "${wrapper_dir}" "${doc_dir}" "${share_dir}" "${plugin_dir}"
+	if can_write_to "${exec_dir}" "${wrapper_dir}" "${doc_dir}" "${share_dir}" "${plugin_dir}" "${man_dir}"
 	then
 	  # Prefix location success -> Recommend prefix install
 	    if ver_bose; then echo "User \"${USERNAME}\" has write access to current prefixed locations."; fi
@@ -702,7 +720,7 @@ interactive_install()
 
     set_prefix "${str_defaultprefix}"
 
-    if can_write_to "${exec_dir}" "${wrapper_dir}" "${doc_dir}" "${share_dir}" "${plugin_dir}"
+    if can_write_to "${exec_dir}" "${wrapper_dir}" "${doc_dir}" "${share_dir}" "${plugin_dir}" "${man_dir}"
     then
 	    # Default location success -> Recommend standard install
 	if ver_bose; then echo "User \"${USERNAME}\" has write access to default locations. Prefix [${prefix}]"; fi
@@ -717,7 +735,7 @@ interactive_install()
 	    if ver_bose; then echo "Trying prefix [${HOME}]..."; fi
 	    set_prefix "${HOME}"
 
-	    if can_write_to "${exec_dir}" "${wrapper_dir}" "${doc_dir}" "${share_dir}" "${plugin_dir}"
+	    if can_write_to "${exec_dir}" "${wrapper_dir}" "${doc_dir}" "${share_dir}" "${plugin_dir}" "${man_dir}"
 	    then
 		# Prefix [~/.] success -> Recommend home install
 		if ver_bose; then echo "User \"${USERNAME}\" has write access to locations with prefix [${prefix}]."; fi
@@ -810,6 +828,10 @@ generate_wrapper()
 
     wrapper_contain="#!/bin/sh
 
+# Required for Session Management
+OPERA_SCRIPT_PATH=$0
+export OPERA_SCRIPT_PATH
+
 # Location of the Opera binaries
 OPERA_BINARYDIR=${str_localdirexec}
 export OPERA_BINARYDIR
@@ -827,7 +849,7 @@ do
   else
       case \$arg in
           --binarydir*|-binarydir*) toset=OPERA_BINARYDIR ;;
-          --personaldir*|-personaldir*) toset=OPERA_PERSONALDIR ;;
+          --personaldir*|-personaldir*|--pd*|-pd*) toset=OPERA_PERSONALDIR ;;
           -style)
               _QTSTYLE_FROM_CMDLINE_='YES'
               ;;
@@ -1032,6 +1054,13 @@ wrapper_contain="${wrapper_contain}
 
 # Make sure the compat libraries are found
 test -d /usr/local/lib/compat/ && LD_LIBRARY_PATH=\"\${LD_LIBRARY_PATH}:/usr/local/lib/compat/\"
+"
+	;;
+    SunOS*)
+wrapper_contain="${wrapper_contain}	
+
+# Make sure libstdc++.so.6 is found on Solaris 10.
+test -d /usr/sfw/lib/ && LD_LIBRARY_PATH=\"\${LD_LIBRARY_PATH}:/usr/sfw/lib/\"
 "
 	;;
 esac
@@ -1112,6 +1141,7 @@ run_install()
     can_write_to ${exec_dir} || error access ${exec_dir}
     can_write_to ${wrapper_dir} || error access ${wrapper_dir}
     can_write_to ${doc_dir} || error access ${doc_dir}
+    can_write_to ${man_dir} || error access ${man_dir}
     can_write_to ${share_dir} || error access ${share_dir}
     can_write_to ${plugin_dir} || error access ${plugin_dir}
 
@@ -1163,6 +1193,15 @@ run_install()
     generate_wrapper
     chmod $chmodv 755 $wrapper_dir/opera
 
+    # Manual page
+    debug_msg 1 "Manual page"
+
+    mkdir $mkdirv $mkdirp ${man_dir}
+    chmod $chmodv 755 ${man_dir}
+    mkdir $mkdirv $mkdirp ${man_dir}/man1
+    chmod $chmodv 755 ${man_dir}/man1
+    cp $cpv $cpf man/opera.1 ${man_dir}/man1
+
     # Documentation
     debug_msg 1 "Documentation"
 
@@ -1339,11 +1378,7 @@ run_install()
     if test -z "${OPERADESTDIR}"
     then
 	# System wide configuration files
-	case "${os}" in
-	    FreeBSD|OpenBSD|NetBSD)	config_dir="/usr/local/etc";;
-	    *)				config_dir="/etc";;
-	esac
-
+	config_dir="/etc"
 	if can_write_to "$config_dir"
 	then
 	    echo
@@ -1403,7 +1438,9 @@ run_install()
 		echo
 	    fi
 	fi
-	echo "Start with \$PATH/opera, $wrapper_dir/opera or ./opera"
+	echo "Be sure to include $wrapper_dir in your PATH or invoke it as"
+	echo "$wrapper_dir/opera or ./opera; and include $man_path in your MANPATH"
+	echo "to make 'man opera' work, or invoke 'man -M $man_path opera'"
     fi # ver_bose
 }
 
@@ -1781,27 +1818,53 @@ mandrake()
     fi
 }
 
+huntdirs()
+{
+    # $GNOME2PATH and $GNOMEPATH skipped (too few hits google site:gnome.org)
+    # http://docs.kde.org/userguide/environment-variables.html
+    echo ${GNOME2_PATH}:${KDEDIRS}:${GNOME_PATH}:${KDEDIR}:/usr:/opt/gnome:/opt/kde3 \
+    | tr : '\012' | sed -e 's:$:'"/$1:"
+}
+
+pathdirs()
+{
+    # Places to look for executables, one per line:
+    echo $PATH | tr : '\012'
+    huntdirs bin
+}
+
 xdg()
 {   # http://standards.freedesktop.org
-    if update-desktop-database --help >/dev/null 2>&1; then
-
-	for ICON_DIR in ${XDG_DATA_DIRS}/icons/hicolor /usr/share/pixmaps/hicolor; do test -d ${ICON_DIR} && break; done
+    UDD=''
+    for BIN_DIR in `pathdirs`; do
+	test -x ${BIN_DIR}/update-desktop-database || continue
+	UDD=${BIN_DIR}/update-desktop-database; break
+    done
+    
+    # http://standards.freedesktop.org/icon-theme-spec/icon-theme-spec-latest.html
+    if test "$UDD"; then
+	for ICON_DIR in `echo ${XDG_DATA_DIRS}:/usr/local/share:/usr/share|tr : '\012'|sed -e '/^$/d;s:$:/icons/hicolor:'` /usr/share/pixmaps/hicolor; do
+	    test -d ${ICON_DIR} && break
+	done
 
 	if   test ! -d ${ICON_DIR}; then echo "Could not find icon installation directory, icons not installed." >&2
 	elif test ! -w ${ICON_DIR}; then echo "Directory \"${ICON_DIR}\" not writable by user \"${USER}\", icons not installed." >&2
 	else
-	    test -d ${ICON_DIR}/48x48/apps && test -w ${ICON_DIR}/48x48/apps && cp $cpv $share_dir/images/opera_48x48.png $DIR_HI/48x48/apps/opera.png
-	    test -d ${ICON_DIR}/32x32/apps && test -w ${ICON_DIR}/32x32/apps && cp $cpv $share_dir/images/opera_32x32.png $DIR_HI/32x32/apps/opera.png
-	    test -d ${ICON_DIR}/22x22/apps && test -w ${ICON_DIR}/22x22/apps && cp $cpv $share_dir/images/opera_22x22.png $DIR_HI/22x22/apps/opera.png
+	    for RESOLUTION in 48x48 32x32 22x22; do
+		TO_DIR=${ICON_DIR}/${RESOLUTION}/apps
+		test -d ${TO_DIR} && test -w ${TO_DIR} && cp $cpv $share_dir/images/opera_${RESOLUTION}.png ${TO_DIR}/opera.png
+	    done
 	fi
-
-	for SHORTCUT_DIR in ${XDG_DATA_HOME}/applications /usr/local/share/applications /usr/share/applications; do test -d ${SHORTCUT_DIR} && break; done
-
+	
+	for SHORTCUT_DIR in ${XDG_DATA_HOME}/applications /usr/local/share/applications /usr/share/applications; do
+	    test -d ${SHORTCUT_DIR} && break;
+	done
+	
 	if   test ! -d ${SHORTCUT_DIR}; then echo "Could not find shortcut installation directory, desktop entry not installed." >&2; return
 	elif test ! -w ${SHORTCUT_DIR}; then echo "Directory \"${SHORTCUT_DIR}\" not writable by user \"${USER}\", desktop entry not installed." >&2; return
 	fi
 	generate_desktop ${SHORTCUT_DIR} xdg
-	update-desktop-database
+	${UDD}
     else
 	icons
 	gnome
@@ -1813,7 +1876,7 @@ xdg()
 }
 
 # These are the only variables the needs to be changed
-opera_version='8.52-20060201.5'
+opera_version='8.54-20060330.5'
 
 debug_level='0' # From 0 to 2
 
